@@ -1,3 +1,6 @@
+from ftThanos.log import *
+
+
 def build_ret(elem):
 	ret = {
 		'properties' : elem,
@@ -170,4 +173,5 @@ def get_properties(elem):
 		"formula" : ret_formula
 	}
 	ret = function[elem['type']](elem)
+	debug(f'NOTION :: Return get {elem["type"]} format')
 	return ret
